==> hbase-shaded-jersey-3.4.0-sources.jar: org/apache/hbase/thirdparty/org/glassfish/jersey/server/ManagedAsyncExecutorLiteral.java <==
/*
 * Copyright (c) 2015, 2019 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.apache.hbase.thirdparty.org.glassfish.org.apache.hbase.thirdparty.jersery.server;

import org.apache.hbase.thirdparty.org.glassfish.org.apache.hbase.thirdparty.jersery.internal.inject.AnnotationLiteral;

/**
 * {@link ManagedAsyncExecutor} annotation literal.
 * <p>
 * This class provides a {@link #INSTANCE constant instance} of the {@code @ManagedAsyncExecutor} annotation to be used
 * in method calls that require use of annotation instances.
 * </p>
 *
 * @author Marek Potociar
 * @since 2.18
 */
@SuppressWarnings("ClassExplicitlyAnnotation")
public final class ManagedAsyncExecutorLiteral extends AnnotationLiteral<ManagedAsyncExecutor> implements ManagedAsyncExecutor {

    /**
     * {@code ManagedAsyncExecutor} annotation instance.
     */
    public static final ManagedAsyncExecutor INSTANCE = new ManagedAsyncExecutorLiteral();

    private ManagedAsyncExecutorLiteral() {
    }
}

==> hbase-shaded-jersey-4.1.1-sources.jar: org/apache/hbase/thirdparty/org/glassfish/jersey/server/ManagedAsyncExecutorLiteral.java <==
/*
 * Copyright (c) 2015, 2019 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.apache.hbase.thirdparty.org.glassfish.org.apache.hbase.thirdparty.jersey.server;

import org.apache.hbase.thirdparty.org.glassfish.org.apache.hbase.thirdparty.jersey.internal.inject.AnnotationLiteral;

/**
 * {@link ManagedAsyncExecutor} annotation literal.
 * <p>
 * This class provides a {@link #INSTANCE constant instance} of the {@code @ManagedAsyncExecutor} annotation to be used
 * in method calls that require use of annotation instances.
 * </p>
 *
 * @author Marek Potociar
 * @since 2.18
 */
@SuppressWarnings("ClassExplicitlyAnnotation")
public final class ManagedAsyncExecutorLiteral extends AnnotationLiteral<ManagedAsyncExecutor> implements ManagedAsyncExecutor {

    /**
     * {@code ManagedAsyncExecutor} annotation instance.
     */
    public static final ManagedAsyncExecutor INSTANCE = new ManagedAsyncExecutorLiteral();

    private ManagedAsyncExecutorLiteral() {
    }
}
